# Tati-tools 

This is a set of helper tools for computer vision tasks.

### Includes

* Configs parsing
* Tools for deep learning models
* Common PyTorch routines (fix random seed, load, save)
* Logging setups and examples
* Losses: Focal loss, Jaccard loss, Dice losses and combination of losses.
* Visualization of computer vision predictions
* Metrics for CV tasks 
* Image, bboxes and masks helpers
* Sample datasets


### Installation

pip install -U tati-tools

pip install git+https://github.com/tatigabru/tati-tools